
/**
 * Conference contains an array of tracks, each of which contains an array of
 * sessions, each of which contains an array of paper.
 * 
 * @author janara
 *
 */
public class Conference {
    
    // The array of tracks.
    private Track[] tracks;
    
    // The number of parallel tracks.
    private int parallelTracks;
    
    // The number of sessions in a track.
    private int sessionsInTrack;
    
    // The number of papers in a session.
    private int papersInSession;
    
    /**
     * Constructor for Conference.
     * 
     * @param parallelTracks is the number of parallel tracks.
     * @param sessionsInTrack is the number of sessions in a track.
     * @param papersInSession is the number of papers in a session.
     */
    public Conference(int parallelTracks, 
                      int sessionsInTrack, 
                      int papersInSession) {
        this.parallelTracks = parallelTracks;
        this.sessionsInTrack = sessionsInTrack;
        this.papersInSession = papersInSession;
        initTracks(parallelTracks, sessionsInTrack, papersInSession);
        
    }
    
    /**
     * Initialize the tracks.
     * @param parallelTracks is the number of parallel tracks.
     * @param sessionsInTrack is the number of sessions in a track.
     * @param papersInSession is the number of papers in a session.
     */
    private void initTracks(int parallelTracks, 
                            int sessionsInTrack, 
                            int papersInSession) {
        tracks = new Track[parallelTracks];
        for (int i = 0; i < parallelTracks; i++) {
            Track tempTrack = new Track(sessionsInTrack);
            for (int j = 0; j < sessionsInTrack; j++) {
                Session tempSession = new Session(papersInSession);
                tempTrack.setSession(j, tempSession);
            }
            tracks[i] = tempTrack;
        }
    }
    
    /**
     * Gets the number of parallel tracks.
     * @return the number of parallel tracks.
     */
    public int getParallelTracks() {
        return parallelTracks;
    }
    
    /**
     * Gets the number of sessions in a track.
     * @return the number of sessions in a track.
     */
    public int getSessionsInTrack() {
        return sessionsInTrack;
    }
    
    /**
     * Gets the number of papers in a session.
     * @return the number of papers in a session.
     */
    public int getPapersInSession() {
        return papersInSession;
    }
    
    /**
     * Gets the track at the specified index.
     * @param index is the index of the specified track.
     * @return the track
     */
    public Track getTrack(int index) {
        if (index < tracks.length) {
            return tracks[index];
        } else {
            throw new IndexOutOfBoundsException();
        }
    }
    
    /**
     * Sets the paper in the specified slot to the given paper id.
     * @param trackIndex is the track index.
     * @param sessionIndex is the session index.
     * @param paperIndex is the paper index.
     * @param paperId is the id of the paper.
     * @throws IndexOutOfBoundsException
     */
    public void setPaper(int trackIndex, 
                         int sessionIndex, 
                         int paperIndex, 
                         int paperId)  throws IndexOutOfBoundsException {
        if (tracks.length > trackIndex) {
            Track curTrack = tracks[trackIndex];
            curTrack.setPaper(sessionIndex, paperIndex, paperId);
        } else {
            throw new IndexOutOfBoundsException();
        }
    }
    
    public String toString() {
        String string = "";
        
        for (int i = 0; i < sessionsInTrack; i++) {
            for (int j = 0; j < parallelTracks; j++) {
                for (int k = 0; k < papersInSession; k++) {
                    string += tracks[j].getSession(i).getPaper(k)+" ";
                }
                if (j != parallelTracks-1) {
                    string += "| ";
                }
            }
            string += "\n";
        }
        
        return string;
    }
}
