
/**
 * Track maintains an array of sessions.
 * 
 * @author janara
 *
 */
public class Track {
    
    // The array of sessions.
    Session[] sessions;
    
    public Track(int sessionsInTrack) {
        sessions = new Session[sessionsInTrack];
    }
    
    /**
     * Set the paper at the slot index to the specified paper id number.
     * 
     * @param sessionIndex is the session to modify.
     * @param paperIndex is the index of the paper.
     * @param paperId is the id number of the paper.
     * @throws IndexOutOfBoundsException
     */
    public void setPaper(int sessionIndex, 
                         int paperIndex, 
                         int paperId) 
            throws IndexOutOfBoundsException {
        if (sessions.length > sessionIndex) {
            Session curSession = sessions[sessionIndex];
            curSession.setPaper(paperIndex, paperId);
        } else {
            throw new IndexOutOfBoundsException();
        }
    }
    
    /**
     * Get the number of sessions in the track.
     * 
     * @return the number of sessions in the track.
     */
    public int getNumberOfSessions() {
        return sessions.length;
    }
    
    /**
     * Get a specified session.
     * 
     * @param index is the index of the session in question.
     * @return the session at the index.
     * @throws IndexOutOfBoundsException
     */
    public Session getSession(int index) throws IndexOutOfBoundsException {
        if (index < sessions.length) {
            return sessions[index];
        } else {
            throw new IndexOutOfBoundsException();
        }
    }
    
    /**
     * Set the session at the specified index to the new session.
     * 
     * @param index is the index of the session.
     * @param session is the new session
     * @throws IndexOutOfBoundsException
     */
    public void setSession(int index, 
                           Session session) 
            throws IndexOutOfBoundsException {
        if (index < sessions.length) {
            sessions[index] = session;
        } else {
            throw new IndexOutOfBoundsException();
        }
    }
}
